==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/VSphereClusterDeprovisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VSphereClusterDeprovisionBuilder extends VSphereClusterDeprovisionFluentImpl<VSphereClusterDeprovisionBuilder> implements VisitableBuilder<VSphereClusterDeprovision,VSphereClusterDeprovisionBuilder>{
  public VSphereClusterDeprovisionBuilder() {
    this(false);
  }
  public VSphereClusterDeprovisionBuilder(Boolean validationEnabled) {
    this(new VSphereClusterDeprovision(), validationEnabled);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent) {
    this(fluent, false);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VSphereClusterDeprovision(), validationEnabled);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent,VSphereClusterDeprovision instance) {
    this(fluent, instance, false);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent,VSphereClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withVCenter(instance.getVCenter());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovision instance) {
    this(instance,false);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withVCenter(instance.getVCenter());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  VSphereClusterDeprovisionFluent<?> fluent;
  Boolean validationEnabled;
  public VSphereClusterDeprovision build() {
    VSphereClusterDeprovision buildable = new VSphereClusterDeprovision(fluent.getCertificatesSecretRef(),fluent.getCredentialsSecretRef(),fluent.getVCenter());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/VSphereClusterDeprovisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VSphereClusterDeprovisionBuilder extends VSphereClusterDeprovisionFluent<VSphereClusterDeprovisionBuilder> implements VisitableBuilder<VSphereClusterDeprovision,VSphereClusterDeprovisionBuilder>{
  public VSphereClusterDeprovisionBuilder() {
    this(false);
  }
  public VSphereClusterDeprovisionBuilder(Boolean validationEnabled) {
    this(new VSphereClusterDeprovision(), validationEnabled);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent) {
    this(fluent, false);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VSphereClusterDeprovision(), validationEnabled);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent,VSphereClusterDeprovision instance) {
    this(fluent, instance, false);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovisionFluent<?> fluent,VSphereClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new VSphereClusterDeprovision());

    if (instance != null) {
      fluent.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withVCenter(instance.getVCenter());
      fluent.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withVCenter(instance.getVCenter());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovision instance) {
    this(instance,false);
  }
  public VSphereClusterDeprovisionBuilder(VSphereClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new VSphereClusterDeprovision());

    if (instance != null) {
      this.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withVCenter(instance.getVCenter());
      this.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withVCenter(instance.getVCenter());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  VSphereClusterDeprovisionFluent<?> fluent;
  Boolean validationEnabled;
  public VSphereClusterDeprovision build() {
    VSphereClusterDeprovision buildable = new VSphereClusterDeprovision(fluent.buildCertificatesSecretRef(),fluent.buildCredentialsSecretRef(),fluent.getVCenter());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
